@@ -38,7 +38,7 @@ static const char * invocation_name = 0;
 void show_help( const char verbose )
   {
   printf( "%s - POSIX/GNU command line argument parser. (C version)\n", Program_name );
-  printf( "See the source file `cmain.c' to learn how to use %s in\n", Program_name );
+  printf( "See the source file 'cmain.c' to learn how to use %s in\n", Program_name );
   printf( "your own programs.\n"
           "\nUsage: %s [options]\n", invocation_name );
   printf( "\nOptions:\n"
@@ -81,7 +81,7 @@ void show_error( const char * const msg, const int errcode, const char help )
     fprintf( stderr, "\n" );
     }
   if( help && invocation_name && invocation_name[0] )
-    fprintf( stderr, "Try `%s --help' for more information.\n",
+    fprintf( stderr, "Try '%s --help' for more information.\n",
              invocation_name );
   }
 
@@ -163,14 +163,14 @@ int main( const int argc, const char * const argv[] )
       {
       const char * const name = optname( code, options );
       if( !name[1] )
-        printf( "option `-%c'", name[0] );
+        printf( "option '-%c'", name[0] );
       else
-        printf( "option `--%s'", name );
+        printf( "option '--%s'", name );
       if( arg[0] )
-        printf( " with argument `%s'", arg );
+        printf( " with argument '%s'", arg );
       }
     else	/* non-option */
-      printf( "non-option argument `%s'", arg );
+      printf( "non-option argument '%s'", arg );
     printf( "\n" );
     }
 
