@@ -42,7 +42,7 @@ const char * invocation_name = 0;
 void show_help( const bool verbose )
   {
   std::printf( "%s - POSIX/GNU command line argument parser. (C++ version)\n", Program_name );
-  std::printf( "See the source file `main.cc' to learn how to use %s in\n", Program_name );
+  std::printf( "See the source file 'main.cc' to learn how to use %s in\n", Program_name );
   std::printf( "your own programs.\n"
                "\nUsage: %s [options]\n", invocation_name );
   std::printf( "\nOptions:\n"
@@ -86,12 +86,12 @@ void show_error( const char * const msg, const int errcode = 0,
     std::fprintf( stderr, "\n" );
     }
   if( help && invocation_name && invocation_name[0] )
-    std::fprintf( stderr, "Try `%s --help' for more information.\n",
+    std::fprintf( stderr, "Try '%s --help' for more information.\n",
                   invocation_name );
   }
 
 
-void internal_error( const char * const msg ) throw()
+void internal_error( const char * const msg )
   {
   std::fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
   std::exit( 3 );
@@ -166,14 +166,14 @@ int main( const int argc, const char * const argv[] )
       {
       const char * name = optname( code, options );
       if( !name[1] )
-        std::printf( "option `-%c'", name[0] );
+        std::printf( "option '-%c'", name[0] );
       else
-        std::printf( "option `--%s'", name );
+        std::printf( "option '--%s'", name );
       if( arg[0] )
-        std::printf( " with argument `%s'", arg );
+        std::printf( " with argument '%s'", arg );
       }
     else	// non-option
-      std::printf( "non-option argument `%s'", arg );
+      std::printf( "non-option argument '%s'", arg );
     std::printf( "\n" );
     }
 
